pub struct Error { /* private fields */ }Expand description
Represents HTTP/2.0 operation errors.
Error covers error cases raised by protocol errors caused by the
peer, I/O (transport) errors, and errors caused by the user of the library.
If the error was caused by the remote peer, then it will contain a
Reason which can be obtained with the reason function.
Implementations