ServiceRequest

Struct ServiceRequest 

pub struct ServiceRequest(/* private fields */);
An service http request

ServiceRequest allows mutable access to request’s internal structures

Implementations

Source

impl ServiceRequest

pub fn into_parts(self) -> (HttpRequest, Payload)

Deconstruct request into parts

pub fn from_parts( req: HttpRequest, pl: Payload, ) -> Result<Self, (HttpRequest, Payload)>

Construct request from parts.

ServiceRequest can be re-constructed only if req hasnt been cloned.

pub fn from_request(req: HttpRequest) -> Result<Self, HttpRequest>

Construct request from request.

HttpRequest implements Clone trait via Rc type. ServiceRequest can be re-constructed only if rc’s strong pointers count eq 1 and weak pointers count is 0.

pub fn into_response<B, R: Into<Response<B>>>( self, res: R, ) -> ServiceResponse<B>

Create service response

pub fn error_response<B, E: Into<Error>>(self, err: E) -> ServiceResponse<B>

Create service response for error

pub fn head(&self) -> &RequestHead

This method returns reference to the request head

pub fn head_mut(&mut self) -> &mut RequestHead

This method returns reference to the request head

pub fn uri(&self) -> &Uri

Request’s uri.

pub fn method(&self) -> &Method

Read the Request method.

pub fn version(&self) -> Version

Read the Request Version.

pub fn headers(&self) -> &HeaderMap

Returns request’s headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns mutable request’s headers.

pub fn path(&self) -> &str

The target path of this Request.

pub fn query_string(&self) -> &str

The query string in the URL.

E.g., id=10

pub fn peer_addr(&self) -> Option<SocketAddr>

Peer socket address

Peer address is actual socket address, if proxy is used in front of Eternal http server, then peer address would be address of this proxy.

To get client connection information ConnectionInfo should be used.

pub fn connection_info(&self) -> Ref<'_, ConnectionInfo>

Get ConnectionInfo for the current request.

pub fn match_info(&self) -> &Path<Url>

Get a reference to the Path parameters.

Params is a container for url parameters. A variable segment is specified in the form {identifier}, where the identifier can be used later in a request handler to access the matched value for that segment.

pub fn match_info_mut(&mut self) -> &mut Path<Url>

Get a mutable reference to the Path parameters.

pub fn resource_map(&self) -> &ResourceMap

Get a reference to a ResourceMap of current application.

pub fn app_config(&self) -> &AppConfig

Service configuration

pub fn app_data<T: 'static>(&self) -> Option<Data<T>>

Get an application data stored with App::data() method during application configuration.

pub fn set_payload(&mut self, payload: Payload)

Set request payload.